Crate wasmer_middlewares_near
wasmer_
middlewares_
near
1.0.1
All Items
Crate Items
Re-exports
Modules
Crate
wasmer_
middlewares_
near
Re-exports

pub use metering::
Metering
;
Modules

metering
metering
is a middleware for tracking how many operators are executed in total and putting a limit on the total number of operators executed.